# ---------------------------------------- #
#     E-Z Reader Simulation Analyses       #
#     Matthew J. Abbott                    #
#     12.07.14                             #
# ---------------------------------------- #


# Load required packages

require(lme4)
require(plyr)
require(ggplot2)
require(MASS)
require(lattice)
require(devtools)
require(reshape2)
require(xlsx)
try(source('~/Gilligan/Experiment 1/Analysis/functions.R'))


# -------------------------------------- #
#         SIMULATION 1                   #
# -------------------------------------- #


# Simulate the experiment using the cloze values for the target words for both preview conditions. Here this is suggesting that even though the upcoming word is 'the' in half of the trials, the cloze probability given is for the intended target word and not 'the'.

# Default E-Z Reader parameters


# Read in the target word data file

sim1 <- read.csv('~/Gilligan/Simulation 1/sim1_dat.csv', header=T)

# Pr.S. is the relevant DV here, and IV is cond (I need to remap those)

with(sim1, tapply(pS_tar, list(cond), mean, na.rm=T))

sim1$pred <- ifelse(sim1$cond %in% c(1,2), "Predictable", "Unpredictable")
sim1$prev <- ifelse(sim1$cond %in% c(1,3), "Target", "The")


################################
#       TARGET WORD            #
################################


tarskip.dat <- summarySE(sim1, measurevar="pS_tar", groupvars=c("prev","pred"),na.rm=T)

# Plot Target Skipping: Sim1
  
  ggplot(tarskip.dat, aes(x=pred, y=pS_tar, group=prev, color=prev, ymax=max(tarskip.dat$pS_tar)+max(tarskip.dat$se)), position=position_dodge(.3)) +
  geom_line(aes(linetype=prev), size=1.5, position=position_dodge(.3)) +
  #geom_errorbar(width=.2, aes(ymin=pS_tar-se, ymax=pS_tar+se), position=position_dodge(.3)) +
  geom_point(aes(shape=prev), size=8, fill="white", position=position_dodge(.3)) +
  scale_colour_manual(values = c("blue","red")) +
  
  # Set legend title and info
  scale_shape_manual(name="prev", values=c(21,22)) +
  scale_linetype_discrete(name="prev") +
  xlab("Constraint") + ylab("Skipping Rate") +
  theme_bw() +
  
  ggtitle("Target Word Skipping Rate") +
  # Set all of the title and axis themes
  theme(plot.title = element_text(lineheight=2.0, size=26, face="bold")) +
  theme(axis.title=element_text(size=22)) +
  theme(axis.text=element_text(size=18)) +
  theme(legend.title = element_text(size=22)) +
  theme(legend.text = element_text(size=18)) +
  theme(legend.justification=c(1,1), legend.position=c(1,1))


###############################
#     PRE-TARGET WORD         #
###############################


# What is happening on the pre-target word?

with(sim1, tapply(pS_pre, list(pred,prev), mean, na.rm=T))
